/*
    Sir
    Autor: Marius Stroe
    Complexitate: O(N logN)
*/

#include <cstdio>
#include <ctime>
#include <cstdlib>
#include <cassert>
#include <map>
#include <set>
#include <vector>
#include <algorithm>
using namespace std;

const char iname[] = "sir.in";
const char oname[] = "sir.out";

const int MAXN = 250005;

#define FOR(i, a, b)  for (int i = (a); i <= (b); ++ i)
#define left(n)  ((n) << 1)
#define right(n) (left(n) + 1)
#define INF  2000000000

int V[MAXN], other[MAXN], bad[MAXN], n, sum, Max[524288], Min[524288], Bad[524288];

map <int, int> M;


inline int getMax(int a, int b) { return a > b ? a : b; }

inline int getMin(int a, int b) { return a < b ? a : b; }

void _update(int n, int lo, int hi)
{
    int mid = (hi + lo) / 2;

    if (hi == lo) {
        Max[n] = Min[n] = other[hi];
        Bad[n] = bad[hi];
        return ;
    }
    _update(left(n), lo, mid), _update(right(n), mid + 1, hi);
    Max[n] = getMax( Max[left(n)], Max[right(n)] );
    Min[n] = getMin( Min[left(n)], Min[right(n)] );
    Bad[n] = Bad[left(n)] || Bad[right(n)];
}

int query_bad(int n, int lo, int hi, int a, int b)
{
    int mid = (hi + lo) / 2, is_bad = 0;

    if (a <= lo && hi <= b)
        return Bad[n];
    if (a <= mid)
        is_bad |= query_bad(left(n), lo, mid, a, b);
    if (mid < b)
        is_bad |= query_bad(right(n), mid + 1, hi, a, b);
    return is_bad;
}

int query_max(int n, int lo, int hi, int a, int b)
{
    int mid = (hi + lo) / 2, ret = 0;

    if (a <= lo && hi <= b)
        return Max[n];

    if (a <= mid)
        ret = getMax( ret, query_max(left(n), lo, mid, a, b) );
    if (mid < b)
        ret = getMax( ret, query_max(right(n), mid + 1, hi, a, b) );
    return ret;
}

int query_min(int n, int lo, int hi, int a, int b)
{
    int mid = (hi + lo) / 2, ret = INF;

    if (a <= lo && hi <= b)
        return Min[n];

    if (a <= mid)
        ret = getMin( ret, query_min(left(n), lo, mid, a, b) );
    if (mid < b)
        ret = getMin( ret, query_min(right(n), mid + 1, hi, a, b) );
    return ret;
}

int check_input(void) {
    set <int> S;
    FOR (i, 1, n) {
        if (S.find(V[i]) != S.end())
            return 0;
        S.insert(V[i]);
    }
    return 1;
}

int main(void)
{
    FILE *fi = fopen(iname, "r");
    FILE *fo = fopen(oname, "w");

    assert( fscanf(fi, "%d %d", &n, &sum) == 2 );
    FOR (i, 1, n)
        assert( fscanf(fi, "%d", &V[i]) == 1 );

    fclose(fi);

    assert( check_input() );

    FOR (i, 1, n)  M[ V[i] ] = i;
    FOR (i, 1, n) {
        map <int, int>::iterator it = M.find(sum - V[i]);

        if (it != M.end() && (*it).second != i)
            other[i] = (*it).second;
        else
            bad[i] = 1;
    }

    _update(1, 1, n);

    int length = 0, first;

    FOR (i, 1, n) if (!bad[i])
    {
        int a = i, b = other[i];
        if (a > b)
            swap(a, b);
        if ( query_bad(1, 1, n, a, b) == 0 )
        {
            int lo = query_min(1, 1, n, a, b);
            int hi = query_max(1, 1, n, a, b);

            if (a <= lo && hi <= b)
            {
                if (length < b-a+1)
                    length = b-a+1, first = a;
                else if (length == b-a+1)
                {
                    if (first > a)
                        first = a;
                }
            }
        }
    }

    fprintf(fo, "%d %d %d\n", length, first, first + length - 1);

    fclose(fo);
    return 0;
}
